@@ -8,6 +8,7 @@
 #define CONTACTIMPORTER_H
 
 #include <KContacts/VCardConverter>
+#include <QFileDialog>
 #include <QObject>
 
 class ContactImporter : public QObject
@@ -15,9 +16,12 @@ class ContactImporter : public QObject
     Q_OBJECT
 public:
     explicit ContactImporter(QObject *parent = nullptr);
-    Q_INVOKABLE void importVCards(const QUrl &path);
+    Q_INVOKABLE void startImport();
 
 private:
+    Q_SLOT void importVCards(const QUrl &path);
+
+    std::unique_ptr<QFileDialog> m_dialog;
     KContacts::VCardConverter m_converter;
 };
 
