@@ -13,7 +13,7 @@
 #include <KPluginFactory>
 
 #include <KContacts/VCardConverter>
-#include <KPeople/Widgets/Actions>
+#include <KPeople/Actions>
 #include <KPeopleBackend/AbstractContact>
 
 KPeopleActionsPlugin::KPeopleActionsPlugin(QObject *parent, const QVariantList &args)
